package com.javaseleniumtemplate.tests;

import com.javaseleniumtemplate.bases.TestBase;
import com.javaseleniumtemplate.flows.LoginFlows;
import com.javaseleniumtemplate.flows.RetiradaPlanejamentoFlows;
import com.javaseleniumtemplate.pages.RetiradaPlanejamentoPage;
import org.testng.annotations.Test;

public class RetiradaPlanejamentoTests extends TestBase {

    RetiradaPlanejamentoPage retiradaPlanejamentoPage;
    RetiradaPlanejamentoFlows retiradaPlanejamentoFlows;
    LoginFlows loginFlows;


    //Realizar todo o processo de lançamento da retirada, edição das quantidade, exclusão, verificação do resumo, atualização do estoque
    //exclusão de apenas uma retira e também de todas por meio do botão de excluir retirada
    @Test
    public void realizarRetiradaTipoPrato() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarTipoPrato();
        retiradaPlanejamentoPage.refresh();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.verificarTipoPratoAdicionado();
        retiradaPlanejamentoPage.adicionarProdutoCreosoto();
        retiradaPlanejamentoPage.editarQuantidadesProd();
        retiradaPlanejamentoPage.excluirProduto();
        retiradaPlanejamentoPage.verificarProdutoAdicionado();
        retiradaPlanejamentoPage.adicionarSegundoTipoPrato("Salvo com sucesso.");
        retiradaPlanejamentoPage.verificarSegundoTipoPratoAdd();
        retiradaPlanejamentoPage.refresh();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.verificarResumo();
        retiradaPlanejamentoPage.excluirTipoPrato();
        retiradaPlanejamentoPage.atualizarEstoque();
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //editar o valor das quantidades na tela de produtos, através do inLine sem acessar o produto
    @Test
    public void editarNaTelaPrincipalRetiradaTipoPrato() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarTipoPrato();
        retiradaPlanejamentoPage.verificarTipoPratoAdicionado();
        retiradaPlanejamentoPage.editarQuantExtraTelaProdutoRetTipoPrato();
        retiradaPlanejamentoPage.verificarValEdicaoQuantProdRetTipoPrato("Quantidade Extra");
        retiradaPlanejamentoPage.editarQuantConsumidaProdutoRetTipoPrato();
        retiradaPlanejamentoPage.verificarValEdicaoQuantProdRetTipoPrato("Quantidade Consumida");
        retiradaPlanejamentoPage.refresh();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar o mesmo tipo de prato mais de uma vez. Na segunda vez deve informar que já existe item cadastrado
    @Test
    public void tentarAddMesmoTipoPratoDuasVezes() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarTipoPrato();
        retiradaPlanejamentoPage.adicionarSegundoTipoPrato("Salvo com sucesso.");
        retiradaPlanejamentoPage.verificarSegundoTipoPratoAdd();
        retiradaPlanejamentoPage.adicionarSegundoTipoPrato("Já existe item cadastrado.");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //verificar se o filtro inicial está com obrigatoriedade em todos os campos
    @Test
    public void testarCamposObrigatoriosFiltroInicial() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.limparCamposApliFiltroIni();
        retiradaPlanejamentoPage.verificarMensObrigaFiltroIni();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar confirmar o filtro da nova retirada, com uma data inválida. Esse filtro deve ser impedido e no fim será verificado qual a data ficou no campo
    @Test
    public void novaRetiradaDataInvalida() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroIniDataInvalida("40/22/3200", "Tipo Prato");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //verificar se o filtro nova retirada está com obrigatoriedade em todos os campos
    @Test
    public void testarCamposObrigatoriosFilNovaRetirada() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.verificarMensObrigaFilNovaRetirada("29/08/2022", "Tipo Prato");

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar uma retirada com campos vazios e logo após adicionar com dados. No fim do teste, excluir a retirada adicionada
    @Test
    public void adicionarRetiradaCamposVazios() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022","Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.camposObrigatoriosAddRetirada();
        retiradaPlanejamentoPage.refresh();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022","Tipo Prato");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022","Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //testar ação exibir romaneio na retirada tipo de prato
    @Test
    public void acaoExibirRomaneioRetTipoPrato() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarTipoPrato();
        retiradaPlanejamentoPage.verificarAcaoExibirRomaneio("Tipo Prato");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar um novo produto com campos vazios
    //na sequência preencher os campos e adicionar o produto
    //no fim excluir a retirada adicionada
    @Test
    public void addProdutoCamposVazios() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarTipoPrato();
        retiradaPlanejamentoPage.produtoComCamposVazios();
        retiradaPlanejamentoPage.excluirProduto();
        retiradaPlanejamentoPage.verificarProdutoAdicionado();
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //na tela de cadastro da retirada de tipo de prato, clicar no botão pesquisar e escrever o valor no campo procurar
    //por fim selecionar o valor desejadado e verificar se no campo está o valor selecionado
    //o teste será feito nos campos: tipo de prato, prato, produto, e tipo retirada
    @Test
    public void escreverValorNoCampoProcurarRetiraTipoPrato() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.escreverValorNoCampoProcurarReiradaTipoPrato();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //iniciar uma retirada e cancelar
    @Test
    public void iniciarECancelarRetirada() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Tipo Prato");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.cancelarRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //Realizar o processo de retirada de um produto em uma data que fique com estoque irregular e exclusão da mesma no fim do processo
    //
    //
    //
//    @Test
//    public void realizarRetiradaProdutoParaEstoqueIrregular() {
//        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
//        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
//        loginFlows = new LoginFlows();
//
//        loginFlows.efetuarLogin();
//        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
//        retiradaPlanejamentoPage.confirmarFiltroRetirada();
//        retiradaPlanejamentoPage.formularioAdicionarRetProduto("Retirada incluída com sucesso, porém ocorreram erros durante a evolução do estoque, verifique o log.");
//        retiradaPlanejamentoPage.erroLog();
//        retiradaPlanejamentoPage.refresh();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.verificarRetiradaProduto();
//        retiradaPlanejamentoPage.refresh();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.excluirRetirada();
//
//        try {
//            Thread.sleep(8000);
//        } catch (InterruptedException e) {
//            e.printStackTrace();
//        }
//    }

    //Realizar o processo de retirada de um produto, a edição e exclusão do mesmo
    @Test
    public void realizarRetiradaProduto() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarRetProduto("Retirada incluída com sucesso.");
        retiradaPlanejamentoPage.verificarRetiradaProduto();
        retiradaPlanejamentoPage.addSegundaRetiradaProduto("Salvo com sucesso.");
        retiradaPlanejamentoPage.verificarSegundaRetiradaProduto();
        retiradaPlanejamentoPage.editarRetiradaProduto();
        retiradaPlanejamentoPage.excluirRetiradaProduto();
        retiradaPlanejamentoPage.atualizarEstoque();
        retiradaPlanejamentoPage.exibirResumoRetiradaProduto();
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //testar ação exibir romaneio na retirada produto
    @Test
    public void acaoExibirRomaneioRetProduto() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarRetProduto("Retirada incluída com sucesso.");
        retiradaPlanejamentoPage.verificarAcaoExibirRomaneio("Produto");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar a retira do mesmo produto duas vezes, na segunda deve ser informado que já existe item cadastrado
    @Test
    public void tentarAdicionarMesmoProdutoDuasVezes() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarRetProduto("Retirada incluída com sucesso.");
        retiradaPlanejamentoPage.verificarRetiradaProduto();
        retiradaPlanejamentoPage.addSegundaRetiradaProduto("Salvo com sucesso.");
        retiradaPlanejamentoPage.verificarSegundaRetiradaProduto();
        retiradaPlanejamentoPage.addSegundaRetiradaProduto("Já existe item cadastrado.");
        retiradaPlanejamentoPage.excluirRetirada();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //tentar adicionar uma retirada de produto, com os campos vazios e em uma data que gere o estoque irregular
    //
    //
    //
    //
//    @Test
//    public void testarCamposObrigRetProduto() {
//        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
//        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
//        loginFlows = new LoginFlows();
//
//        loginFlows.efetuarLogin();
//        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
//        retiradaPlanejamentoPage.confirmarFiltroRetirada();
//        retiradaPlanejamentoPage.addRetProdutoCamposVazios();
//        retiradaPlanejamentoPage.erroLog();
//        retiradaPlanejamentoPage.refresh();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.atualizarEstoqueIrregular();
//        retiradaPlanejamentoPage.excluirRetirada();
//        retiradaPlanejamentoPage.filtroInicial("31/08/2022", "Produto");
//        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
//
//        try {
//            Thread.sleep(8000);
//        } catch (InterruptedException e) {
//            e.printStackTrace();
//        }
//    }

    //na tela de cadastro da retirada de produto, clicar no botão pesquisar e escrever o valor no campo procurar,
    //por fim selecionar o valor desejado e verificar se no campo está o valor selecionado
    //o teste será feito nos campos:produto e tipo retirada
    @Test
    public void escreverValorNoCampoProcurarRetiradaProduto() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.escreverValorNoCampoProcurarReiradaProduto();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    //editar o valor das quantidades na tela de produtos, através do inLine sem acessar o produto na retirada produto
    @Test
    public void editarNaTelaPrincipalRetiradaProduto() {
        retiradaPlanejamentoPage = new RetiradaPlanejamentoPage();
        retiradaPlanejamentoFlows = new RetiradaPlanejamentoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        retiradaPlanejamentoFlows.navegateRetiradaPlanejamento();
        retiradaPlanejamentoPage.filtroInicial("23/09/2022", "Produto");
        retiradaPlanejamentoPage.alertaNaoExisteRetirada();
        retiradaPlanejamentoPage.confirmarFiltroRetirada();
        retiradaPlanejamentoPage.formularioAdicionarRetProduto("Retirada incluída com sucesso.");
        retiradaPlanejamentoPage.verificarRetiradaProduto();
        retiradaPlanejamentoPage.editarQuantExtraTelaPrincipal();
        retiradaPlanejamentoPage.varificarValoresAposEdicaoTelaPrincipal("Quantidade Extra");
        retiradaPlanejamentoPage.editarQuantConsumidaTelaPrincipal();
        retiradaPlanejamentoPage.varificarValoresAposEdicaoTelaPrincipal("Quantidade Consumida");
        retiradaPlanejamentoPage.excluirRetirada();

        try {
            Thread.sleep(8000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

}
